# March 30th, 2021

**Date:** March 30, 2021, at 8am Pacific (your [timezone](https://arewemeetingyet.com/Los%20Angeles/2021-03-30/8:00/Jupyter%20Community%20Call))

[**Discourse:**](https://discourse.jupyter.org/t/jupyter-community-calls/668)

[**Youtube Link**](https://youtu.be/8JQoALd9KTo)

**Please note:**
- Community calls are recorded and posted to this [playlist](https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP)
- These notes will be recorded and posted [here](https://jupyter.readthedocs.io/en/latest/community/community-call-notes/index.html)
- Everyone present is held to the [Jupyter Code of Conduct](https://jupyter.org/conduct)

## Purpose

Think of it as a monthly, virtual JupyterCon. It’s a place to announce and share fun things happening in the Jupyter community.

For more discussion on the format of these calls, see the thread [here](https://discourse.jupyter.org/t/reviving-the-all-jupyter-team-meetings/423).

## Short reports, celebrations, shout-outs

* **Isabela Presedo-Floyd** Congrats to anyone who started the cycle 4 CZI EOSS grant application process! We have several in the community.
* **Nick B**  [jupyter-starters 1.0.2](https://pypi.org/project/jupyter-starters/)
* **Carol W** Darian for his work on the Jupyter Distinguished Contributors.

## Agenda Items

- **Nick B.** Has anyone done `if this then that` in a JupyterHub?
    - General answer is no
    - Something like https://github.com/huginn/huginn?
    - For background, this is https://ifttt.com/
    - Use cases 
- **Tony Fast** schemata library (future traits library that complies more with JSON schema than traitlets)
    - Goal of having types being able to describe themselves. This is a work in progress for IPython.
    - Creates different types of interactive notebook outputs following JSON standards that can allow them to interact with more backends.
- Favorite notebooks/binders/plugins
    - **Simon Li** Unexpected use of binder https://github.com/jupyterhub/jupyter-remote-desktop-proxy/
    - Can you run JupyterHub inside mybinder https://gist.github.com/manics/cd04d42b211dfd6240430ee33349cd49
- **Tony Fast** https://nbviewer.jupyter.org/github/deathbeds/deathbeds.github.io/blob/master/deathbeds/2018-07-31-Testing-notebooks.ipynb
    - https://github.com/jennalandy/notebook-research/blob/master/analysis_notebooks/16_HallOfFame.ipynb
- **Nick B.** https://gist.github.com/bollwyvl/7a128978b8ae89ab02bbd5b84d07a4b7
    - Can we round-trip LaTeX to SymPy https://github.com/bollwyvl/sympy-latex-hypothesis/blob/master/Hypothesize.ipynb
- **Carol Willing** https://github.com/moorepants/pydy-tutorial-human-standing

## Other Links Shared

This is a space to store links shared during community call discussions related to or separate from the agenda items.

- https://w3c.github.io/annotation-aria/
- http://507movements.com/
- http://rescience.github.io/ten-years/
- https://web.mit.edu/music21/
- https://pockit.ai/
- https://www.dexterindustries.com/gopigo3/

## Attendees

|   Name             | Institution          | GitHub Handle                |
|--------------------|----------------------|------------------------------|
| Frédéric Collonval | ARIADNEXT            | @fcollonval |
| Simon Li           | University of Dundee | @manics |
| Carol Willing      | Jupyter              | @willingc |
| Nick Bollweg       | Jupyter, GaTech      | @bollwyvl @nrbgt |
|  Pierre-Olivier Simonard  | Quansight | @pierrotsmnrd|         
| Fatma Tarlaci      | OpenTeams            | @ftarlaci |
| Pete Blois         | Google Colab         | @blois |
| Isabela Presedo-Floyd | Quansight Labs | @isabela-pf |